lsattr
======

List the attributes of a class in a ``repr()``-fiendly way

Example usage
-------------

.. code-block:: python

    Here be dragons...

Installation
------------

The `project <https://pypi.org/project/lsattr/>`_ is on PyPI, so simply run

.. code-block:: bash

    python -m pip install lsattr
